pub async fn submit_shipment_confirmations(
    configuration: &Configuration,
    body: SubmitShipmentConfirmationsRequest
) -> Result<SubmitShipmentConfirmationsResponse, Error>
Submits one or more shipment confirmations for vendor orders. Usage Plans: | Plan type | Rate (requests per second) | Burst | | –– | –– | –– | |Default| 10 | 10 | |Selling partner specific| Variable | Variable | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation. Rate limits for some selling partners will vary from the default rate and burst shown in the table above. For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.